<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
/**
 * Plugin Name: EZcount
 * Plugin URI: https://www.ezcount.co.il
 * Description: invoicing, clearing and paypal integration plugin.
 * Version: 1.11.5
 * Author: EZcount
 * Author URI: https://www.ezcount.co.il
 * Requires at least: 4.4
 * Tested up to: 6.1.1
 * Text Domain: ezcount_payment
 *
 */

$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins' ) );
if ( !in_array( 'woocommerce/woocommerce.php', $active_plugins ) ) {
    add_action( 'admin_notices', 'notice_required_woo' );
}


function notice_required_woo() {
    $error_text = __( 'You must install & activate WooCommerce before installing EZCOUNT plugin!', 'ezcount_payment');
    ?>
    <div class="error notice">
        <p><h1><?php echo esc_html($error_text) ?></h1></p>
    </div>
    <?php
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ),
	function ( $links ) {
		$mylinks = array(
			'<a href="' . esc_url(admin_url( 'admin.php?page=wc-settings&tab=checkout&section=ezcount' )) . '">Settings</a>',
		);

		return array_merge( $links, $mylinks );
	} );

add_action( 'plugins_loaded', 'init_ezcount_gateway_class', 0 );


function init_ezcount_gateway_class() {
	if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
        return;
	}

	/**
	 * Gateway class
	 **/
	class WC_Gateway_EZcount extends WC_Payment_Gateway {
		/**
		 * Constructor for the gateway.
		 */
		public function __construct() {
			$this->id                 = 'ezcount';
			$this->icon               = apply_filters( 'woocommerce_ezcount_gateway_icon', '' );
			$this->has_fields         = false;
			$this->method_title       = __( 'EZcount', 'ezcount_payment' );
			$this->method_description = __( 'Allows payments with ezcount gateway.', 'ezcount_payment' );


			// Define user set variables
			$this->title        = $this->get_option( 'title' );
			$this->description  = $this->get_option( 'description' );
			$this->instructions = $this->get_option( 'instructions', $this->description );
			$this->order_status = $this->get_option( 'order_status', 'completed' );

			$this->api_key                = $this->get_option( 'api_key' );
			$this->user_email             = $this->get_option( 'user_email' );
			$this->doc_type               = $this->get_option( 'doc_type' );
			$this->environment            = $this->get_option( 'environment' );
			$this->clearing_integration   = $this->get_option( 'clearing_integration' );
			$this->paypal_integration     = $this->get_option( 'paypal_integration' );
			$this->debug_mode             = $this->get_option( 'debug_mode' );
			$this->EZcount_paypal_IPN     = $this->get_option( 'EZcount_paypal_IPN' );
			$this->language_list          = $this->get_option( 'language_list' );
			$this->maxpayments_list       = $this->get_option( 'maxpayments_list' );
			$this->checkout_window        = $this->get_option( 'checkout_window' );
			$this->different_account_uuid = $this->get_option( 'different_account_uuid' );

			// Load the settings.
			$this->init_form_fields();
			$this->init_settings();

			add_action( 'woocommerce_receipt_' . $this->id, array( &$this, 'receipt_page' ) );
			// Hooks
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
			add_action( 'woocommerce_api_wc_gateway_' . $this->id, array( $this, 'cc_reponse' ) );
		}

		/**
		 * Initialize Gateway Settings Form Fields
		 */
		public function init_form_fields() {
			$env = array(
				'demo.ezcount.co.il' => 'DEMO',
				'api.ezcount.co.il'  => 'PRODUCTION',
			);
			if ( strpos( get_site_url(), 'localhost' ) !== false ) {
				$env['devapp.ezcount.co.il'] = 'DEV';
			}
			$current_user = wp_get_current_user();
			$defaultEmail = $current_user->user_email;

			$this->form_fields = array(
				'environment'      => array(
					'title'       => __( 'Environment', 'ezcount_payment' ),
					'type'        => 'select',
					'options'     => $env,
					'default'     => 'demo.ezcount.co.il',
					'description' => __( 'Please select environment.', 'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'api_key'          => array(
					'title'       => __( 'API Key', 'ezcount_payment' ),
					'type'        => 'text',
					'description' => __( 'Please insert API Key.', 'ezcount_payment' ),
					'default'     => '',
					'desc_tip'    => true,
					'required'    => true
				),
				'user_email'       => array(
					'title'       => __( 'Developer(!) email address', 'ezcount_payment' ),
					'type'        => 'text',
					'description' => __( 'We will send technical emails, to this address.', 'ezcount_payment' ),
					'default'     => $defaultEmail,
					'desc_tip'    => true,
					'required'    => true
				),
				'checkout_window'  => array(
					'title'       => __( 'Checkout Window Option', 'ezcount_payment' ),
					'type'        => 'select',
					'options'     => array(
						'Redirect' => 'A redirect page for non SSL website',
						'Iframe'   => 'Iframe inside the page itself'
					),
					'default'     => 'Iframe',
					'description' => __( 'Please select Option.', 'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'doc_type'         => array(
					'title'       => __( 'Doc Type', 'ezcount_payment' ),
					'type'        => 'select',
					'options'     => array(
						'320' => 'INVOICE RECEIPT',
						'400' => 'RECEIPT',
						'405' => 'DONATION RECEIPT'
					),
					'description' => __( 'Please select doc type.', 'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'language_list'    => array(
					'title'       => __( 'Defult language list', 'ezcount_payment' ),
					'type'        => 'select',
					'options'     => array( 'he' => 'Hebrew', 'en' => 'English' ),
					'description' => __( 'Please select default language.',
                        'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'maxpayments_list' => array(
					'title'       => __( 'Max Payments',
                        'ezcount_payment' ),
					'type'        => 'select',
					'options'     => array( '1' => '1', '3' => '3', '6' => '6', '12' => '12' ),
					'description' => __( 'Please select default max Payments.',
                        'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'section_title2'   => array(
					'title' => __( 'Other Settings', 'ezcount_payment' ),
					'type'  => 'title',
					'desc'  => '',
				),
				'title'            => array(
					'title'       => __( 'Title', 'ezcount_payment' ),
					'type'        => 'text',
					'description' => __( 'This controls the title which the user sees  during checkout.', 'ezcount_payment' ),
					'default'     => __( 'כרטיס אשראי', 'ezcount_payment' ),
					'desc_tip'    => true,
				),
				'description'      => array(
					'title'       => __( 'Description', 'ezcount_payment' ),
					'type'        => 'text',
					'description' => __( 'The customer will see this description during the checkout.', 'ezcount_payment' ),
					'desc_tip'    => true,
					'default'     => 'תשלום אשראי דרך ezcount.co.il'
				),
				'debug_mode'       => array(
					'title'       => __( 'Debug mode', 'ezcount_payment' ),
					'type'        => 'checkbox',
					'value'       => '1',
					'default'     => 'yes',
					'description' => __( 'will send additional emails to the developer.', 'ezcount_payment' ),
					'desc_tip'    => true,
				),

				'section_title'          => array(
					'title' => __( 'Advanced features', 'ezcount_payment' ),
					'type'  => 'title',
					'desc'  => '',
				),
				'order_status'           => array(
					'title'       => __( 'Order Status', 'ezcount_payment' ),
					'type'        => 'select',
					'class'       => 'wc-enhanced-select',
					'description' => __( 'Choose whether status you wish  after checkout.', 'ezcount_payment' ),
					'default'     => 'wc-completed',
					'desc_tip'    => true,
					'options'     => wc_get_order_statuses()
				),
				'different_account_uuid' => array(
					'title'    => __( 'Key for different account', 'ezcount_payment' ),
					'type'     => 'text',
					'default'  => '',
					'desc_tip' => true
				),
			);

            $isInWooSetting = !empty($_GET['page']) && !empty($_GET['tab']) && !empty($_GET['section']);
			$runIntegrationTest = $isInWooSetting && $_GET['page'] == 'wc-settings' && $_GET['tab'] == 'checkout' && $_GET['section'] == "ezcount";
			if ( $runIntegrationTest ) {
				$integrationStatus        = EZcount_helpers::testIntegration( $this->environment, $this->api_key, $defaultEmail );
				$arr                      = array();
				$arr['integrationStatus'] = array(
					'title'       => $integrationStatus[0] ? "INTEGRATION TEST SUCCESS" : "INTEGRATION TESTING ERROR! please fix the next issue",
					'description' => $integrationStatus[1],
					'type'        => 'title',
				);
				$this->form_fields        = array_merge( $arr, $this->form_fields );
			}
		}

		/**
		 * Check if this gateway is enabled and available in the user's country
		 */
		public function is_available() {
			/**
			 * always available
			 */
			return true;
		}

		public function payment_fields() {
			$desc = trim( $this->description );
			if ( $desc ) {
				echo "<p>{$desc}</p>";
			}
		}

		/**
		 * Process the payment
		 */
		public function process_payment( $order_id ) {
			global $woocommerce;
			$order = new WC_Order( $order_id );
			if ( $this->checkout_window == 'Iframe' ) {
				$action = array(
					'result'   => 'success',
					'redirect' => $order->get_checkout_payment_url( true )
				);
			} else {
				$action = array(
					'result'   => 'success',
					'redirect' => $this->getFormUrl( $order_id )
				);
			}

			return $action;
		}

		public function getFormUrl( $order_id ) {
			$order      = new WC_Order( $order_id );
			$zc_payment = new WC_Gateway_EZcount();
			$api_key    = $zc_payment->get_option( 'api_key' );
			$sum        = number_format( $order->get_total(), 2, '.', '' );

			//create a one time token...
			//  some users open the clearing twice, and we want to user the right cookie for it
			$secretTransactionId  = wp_generate_uuid4();
			$session              = EZcount_helpers::encrypt( $secretTransactionId . "|" . $order_id, $api_key );
			$sessionBase64Encoded = base64_encode( $session );
			$api_url              = EZcount_helpers::getApiBase() . 'payment/prepareSafeUrl/clearingFormForWeb';
			$data                 = array(
				"sum"                 => $sum,
				"payments"            => $this->maxpayments_list,
				"currency"            => "ILS",
				"secretTransactionId" => $secretTransactionId,
				"successUrl"          => get_site_url() . '?wc-api=WC_Gateway_EZcount&response=success&order_id=' . $order_id . '&ezs=' . $sessionBase64Encoded,
				"failedUrl"           => get_site_url() . '?wc-api=WC_Gateway_EZcount&response=failed&order_id=' . $order_id . '&ezs=' . $sessionBase64Encoded,
			);

			$result = EZcount_helpers::sendJsonRequest( $api_url, $data );

			if ( empty($result->url) ) {
				$response = "Opening payment gateway failed\n
					Here are some technical details:\n
					\nurl: $api_url
					\nrequest data:" . var_export( $data, true ) .
				            "\nresponse data:" . var_export( $result, true ) .
				            "\nresponse lastResponseDebugStr:" . var_export( EZcount_helpers::$lastResponseDebugStr, true );
				wp_mail( $this->user_email, 'Failed to open gateway', $response );

				return "data:,; $response";
			}

			return $result->url;
		}


		public function receipt_page( $order_id ) {
			global $ezcountFormLoaded;
			//if the iframe been called already
			// some users have this bug in their template and they are calling the iframe multiple times,
			// this creates multiple cookies, and the validation fails
			if ( $ezcountFormLoaded ) {
				echo '<span class="EZcountMultipleCallsErr">MULTIPLE_CALLS_TO_IFRAME_PLEASE_FIX</span>';

				return;
			}
			//set the flag to true
			$ezcountFormLoaded = true;

			$ezcountUrl = $this->getFormUrl( $order_id );
			echo '<iframe src="' . esc_url($ezcountUrl) . '"  width="100%" height="999" frameborder="0"></iframe>';
		}


		public function cc_reponse() {
			if ( empty($_GET['response']) || empty($_GET['order_id']) || $_GET['response'] != 'success' || ! (int) $_GET['order_id'] ) {
				$msg = "Auto invoice from EZcount WC plugin failed\n No order ID, or order failed\n\n" . json_encode( EZcount_helpers::sanitizedArray($_GET) );
				wp_mail( $this->user_email, 'Failed to create invoice', $msg );
				echo "VALIDATION ERROR #1 קרתה בעיה, אנא צרו קשר עם בעל החנות";
				die();
			}


			$zc_payment = new WC_Gateway_EZcount();
			$zc_payment->init_form_fields();
			$zc_payment->init_settings();
			$api_key  = $zc_payment->get_option( 'api_key' );
			$order_id = (int) sanitize_text_field(@$_GET['order_id']);
			//get order by id
			$order = new WC_Order( $order_id );

            $ezs = "";
            if (!empty($_GET["ezs"])){
                $ezs = $_GET["ezs"];
            }
			$sessionBase64Encoded = sanitize_text_field($ezs);

			// we have an error unless we found the transaction id
			$errType = 2;

			if ( ! $sessionBase64Encoded ) {
				$errType = 2.1;
			} else {
				$dataEncrypted = base64_decode( $sessionBase64Encoded );
				$dataDecrypted = EZcount_helpers::decrypt( $dataEncrypted, $api_key );
				if ( ! $dataDecrypted ) {
					$errType = 2.2;
				} else {
					list( $secretTransactionId, $sessionOrderId ) = explode( "|", $dataDecrypted );
					if ( ! $secretTransactionId ) {
						$errType = 2.3;
					} elseif ( $sessionOrderId != $order_id ) {
						$errType = 2.5;
					} else {
						//everything is OK, no error
						$errType = 0;
					}
				}
			}


			if ( $errType || ! $secretTransactionId ) {
				$msg = "בעיה באישור הזמנה $order_id,\n
				 התוסף לא הצליח לבצע אישור מול חברת האשראי לאמיתות הסליקה!\n
				 אנא הכנסו אל ממשק הדוחות->סליקה באיזיקאונט, וודאו שהסליקה עברה לפני שאתם נותנים ללקוח את הטובין\n
				  כרגע ההזמנה נכנסה לhold ולא יצאה לה חשבונית.\n\n
				טכנית - ההודעה הזו יכולה לקרות או במקרה של FRAUD או במקרה שעדכנתם את התוסף תוך כדי שהמשתמש היה בתהליך רכישה:\n 
				\n
				מצורף מידע טכני
				\n
				Order ($order_id) transaction Id is empty, can't validate payment \n\n" .
				       json_encode( [
					                    'order_id'            => sanitize_text_field($_GET['order_id']),
					                    "sessionBase64Encoded"   => $sessionBase64Encoded,
					                    "dataEncrypted"       => $dataEncrypted,
					                    "api_key"             => "..." . substr( $api_key, - 10 ),
					                    "dataDecrypted"       => $dataDecrypted,
					                    'secretTransactionId' => $secretTransactionId,
					                    'sessionOrderId'      => $sessionOrderId,
					                    'timezone'            => date_default_timezone_get(),
					                    'server_date'         => date( DATE_ATOM ),
					                    '$_SERVER'            => EZcount_helpers::sanitizedArray($_SERVER),
					                    'siteurl'             => get_site_url()
				                    ],
				                    128 );
				wp_mail( $this->user_email, "VALIDATION ERROR #$errType,  לא הצלחנו לבצע אישור לסליקה עבור הזמנה מספר $order_id", $msg );
				echo "VALIDATION ERROR #$errType לא הצלחנו לבצע אישור לסליקה, אבל יתכן והיא עברה, אנא צרו קשר עם בעל החנות";
				$order->update_status( 'on-hold' );
				die();
			}

			$api_url = EZcount_helpers::getApiBase() . 'payment/validate/'.$secretTransactionId;
			$result  = EZcount_helpers::sendJsonRequest( $api_url );
			$sum = number_format( $order->get_total(), 2, '.', '' );

			//this is a valid request
			if ( ! $result->success ) {
				$msg = "בעיה באישור הזמנה $order_id העסקה עברה אבל היה לה חשש לFraud, אנא בדקו את דוח הסליקה.<br/>\n 
						Order id $order_id transaction validation failed, you might got the money but we failed validate the CC<br/>\n" .
				       json_encode( [
					                    '$result'             => $result,
					                    '$sum'                => $sum,
					                    'secretTransactionId' => $secretTransactionId,
					                    '$_SERVER'            => EZcount_helpers::sanitizedArray($_SERVER)
				                    ] );
				wp_mail( $this->user_email, 'Transaction validation failed', $msg );
				echo "VALIDATION ERROR #3 כרטיס האשראי חוייב אבל היתה בעיה באישור ההזמנה, אנא צרו קשר עם בעלי החנות";
				$order->update_status( 'on-hold' );
				die();
			}

			if ( $result->cgp_payment_total != $sum ) {
				$msg = "בעיה באישור הזמנה $order_id העסקה עברה אבל היה לה חשש לFraud, הסכום שנסלק לא שווה לסכום ההזמנה.<br/>\n 
						Order id $order_id transaction validation failed, you might got the money but we failed validate the CC<br/>\n" .
				       json_encode( [
					                    '$result'             => $result,
					                    '$sum'                => $sum,
					                    'cgp_payment_total'   => $result->cgp_payment_total,
					                    'secretTransactionId' => $secretTransactionId,
					                    '$_SERVER'            => EZcount_helpers::sanitizedArray($_SERVER)
				                    ] );
				wp_mail( $this->user_email, 'Transaction validation failed', $msg );
				echo "VALIDATION ERROR #4 כרטיס האשראי חוייב אבל ישנה בעיה באישור הסליקה, יתכן והיא עברה אבל הסכומים לא נכונים, אנא צרו קשר עם בעלי החנות";
				$order->update_status( 'on-hold' );
				die();
			}
			//--------------------------------Invoice start----------------------------
			$customer_email      = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_email : $order->get_billing_email();
			$customer_first_name = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_first_name : $order->get_billing_first_name();
			$customer_last_name  = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_last_name : $order->get_billing_last_name();
			$customer_address_1  = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_address_1 : $order->get_billing_address_1();
			$customer_city       = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_city : $order->get_billing_city();
			$customer_state      = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_state : $order->get_billing_state();
			$customer_postcode   = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->billing_postcode : $order->get_billing_postcode();
			$order_key           = ( version_compare( WC_VERSION, '2.7', '<' ) ) ? $order->order_key : $order->get_order_key();

			//when the customer is guest and we are having the email only
			if ( ! $customer_first_name && ! $customer_last_name ) {
				//take customer name from the CC
				$customer_first_name = $result->cgp_customer_name;
			}
			// ----------------------- Get order items --------------------------------
			$itemArray = array();
			$items     = array();
			foreach ( $order->get_items() as $item_key => $item_data ) {
				//caculate the item
				$itemPrice = number_format( $order->get_item_total( $item_data, false, false ) + $order->get_item_tax( $item_data, false, false ), 2, '.', '' );

				//WC<3
				if ( ( version_compare( WC_VERSION, '2.7', '<' ) ) ) {
					$item['catalog_number'] = $item_data["product_id"];
					$item['details']        = $item_data['name'];
					$item['amount']         = $item_data['qty'];
					$item['vat_type']       = 'INC';
					$item['price']          = $itemPrice;
				} else {//WC>3
					$qty         = $item_data->get_quantity();
					$product     = $item_data->get_product();
					$productName = $product->get_name();
					if ( ! $productName ) {
						$productName = "General item";
					}
					$item['catalog_number'] = $product->get_id();
					$item['details']        = $productName;
					$item['amount']         = $qty;
					$item['vat_type']       = 'INC';
					$item['price']          = $itemPrice;
				}

				array_push( $itemArray, $item );
			}
			// Iterating through order shipping items
			foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {
				$shippingPrice = number_format( $order->get_total_shipping() + $order->get_shipping_tax(), 2, '.', '' );
				if ( ( version_compare( WC_VERSION, '2.7', '<' ) ) ) {
					$item['catalog_number'] = $shipping_item_obj['method_id'];
					$item['vat_type']       = 'INC';
					$item['amount']         = 1;
					$item['details']        = $shipping_item_obj['name'];
					$item['price']          = $shippingPrice;
				} else {//WC>3
					// Get the data in an unprotected array
					$shipping_data          = $shipping_item_obj->get_data();
					$item['catalog_number'] = $shipping_data['id'];
					$item['vat_type']       = 'INC';
					$item['amount']         = 1;
					$item['details']        = $shipping_data['name'];
					$item['price']          = $shippingPrice;
				}
				array_push( $itemArray, $item );
			}


			//-------------------------------Card details----------------------------

			$cc_number    = sanitize_text_field(@$_GET['last4digits']);
			$cgp_id       = sanitize_text_field(@$_GET['cgp_id']);
			$cc_type_name = sanitize_text_field(@$_GET['ccTypeName']);
			//does not appear in  1 paymnt..
			$cc_num_of_payments = isset( $_GET['numOfPayments'] ) ? sanitize_text_field($_GET['numOfPayments']) : 1;
			$paymentTotal       = sanitize_text_field($_GET['paymentTotal']);

			//-------------------------------XXXXXX----------------------------------

			$customer_address = array();
			if ( trim( $customer_address_1 ) ) {
				$customer_address[] = $customer_address_1;
			}
			if ( trim( $customer_city ) ) {
				$customer_address[] = $customer_city;
			}
			if ( trim( $customer_state ) ) {
				$customer_address[] = $customer_state;
			}
			if ( trim( $customer_postcode ) ) {
				$customer_address[] = $customer_postcode;
			}
			$customer_address = implode( ",", $customer_address );

			$invoice_post =
				array(
					// CUSTOMER credentials
					'api_key'                        => $zc_payment->get_option( 'api_key' ),
					'developer_email'                => $zc_payment->get_option( 'user_email' ),
					'type'                           => $zc_payment->get_option( 'doc_type' ),
					'lang'                           => $zc_payment->get_option( 'language_list' ),
					'customer_name'                  => $customer_first_name . " " . $customer_last_name,
					'customer_email'                 => $customer_email,
					'customer_address'               => $customer_address,
					'item'                           => $itemArray,
					'payment'                        =>
						array(
							array(
								'payment_type'       => 3,/*CC*/
								'payment'            => $paymentTotal,
								'cc_number'          => $cc_number,
								'cc_type_name'       => $cc_type_name,
								'cc_num_of_payments' => $cc_num_of_payments,
								'auto_calc_payments' => true
							)
						),
					'price_total'                    => $paymentTotal,
					'comment'                        => "",
					'transaction_id'                 => $secretTransactionId,
					"cgp_ids"                        => array( $cgp_id ),
					'ua_uuid'                        => $this->different_account_uuid,
					"send_copy"                      => true,
					// reciept will include
					"forceItemsIntoNonItemsDocument" => true,
					// rebalance the values
					"auto_balance"                   => true,
				);

			//invoice!
			$api_url         = EZcount_helpers::getApiBase() . 'createDoc';
			$invoiceResponse = EZcount_helpers::sendJsonRequest( $api_url, $invoice_post );
			if ( ! $invoiceResponse->success ) {
				wp_mail( $zc_payment->get_option( 'user_email' ),
				         'Failed to create invoice',
				         "Auto invoice from EZcount WC plugin failed\n
							Here are some technical details:\n
							Invoice data:" . var_export( $invoice_post, true ) .
				         "EZcount response data:" . var_export( $invoiceResponse, true ) .
				         "Order data:" . var_export( $order, true ) );
			}
			//--------------------------------Invoice end----------------------------
			// Set order status
			$order->update_status( $this->order_status, __( 'payment success. ', get_site_url() ) );
			//Finally redirect page
			$url = get_site_url() . "/checkout/order-received/" . $order_id . "/?key=" . $order_key;

			echo "<script>
				//js redirect because we are maybe inside an Iframe
				window.top.location.href = '$url';
			</script>";
			exit;
		}

	}

	/**
	 * Add EZcount to WC
	 **/
	function add_ezcount_gateway( $methods ) {
		$methods[] = 'WC_Gateway_EZcount';

		return $methods;
	}

	// load the ezcount gateway
	add_filter( 'woocommerce_payment_gateways', 'add_ezcount_gateway' );
}

require_once( plugin_dir_path( __FILE__ ) . 'EZcount_helpers.php' );
