<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class EZcount_helpers {
	static public $lastResponseDebugStr;

	public static function testIntegration( $environment, $api_key, $developer_email ) {
		if ( ! is_email( $developer_email ) ) {
			return [false,"a valid developer email is mandatory"];
		}
		if(!$api_key){
			return [false,"<b>The api key is missing!</b><br/>
							Please login to ezcount.co.il, and fetch your API key from <a target='_blank' href='https://www.ezcount.co.il/EZcountApp.html#/settings/tab_api'>here</a>
							<br/> you may use `4c4b3fd224e0943891588ea5a70d6cb566af3a5b4d506908ca04b30526234551` for testing purposes with the DEMO enviroment"];
		}
		if ( preg_match( "/^([a-f0-9]{64})$/", $api_key ) != 1 ) {
			return [false,"<b>The API key is in wrong format</b>, please copy paste again the API KEY from <a target='_blank' href='https://www.ezcount.co.il/EZcountApp.html#/settings/tab_api'>here</a><br/>
							The current API key value is: $api_key"];
		}
		// call ezcount
		$data["api_key"]         = $api_key;
		$data["developer_email"] = $developer_email;
		//test connection and API KEY
		$res                     = self::_sendJsonRequest( 'https://' . $environment . '/api/documents/testApiKey', $data );

		if ( ! $res || ! $res->success ) {
			return [false,$res->errMsg ? $res->errMsg : self::$lastResponseDebugStr];
		}


		$success = wp_mail( $developer_email, 'EZcount plugin, test developer email', 'This email been sent as part of EZcount plugin integration testing' );
		if (  ! $success ) {
			return [false,"Email integration testing failed, please check your mail server, the function wp_mail is not working properly while trying to send email to $developer_email"];
		}

		//  we are goot!
		return [ true, "<b>INTEGRATION TEST SUCCESS</b> for user " . $res->u_company . " " . $res->u_comp_crn . " at " . $environment ];
	}

	public static function getApiBase() {
		//do validation
		$zc_payment = new WC_Gateway_EZcount();
		$zc_payment->init_form_fields();
		$zc_payment->init_settings();
		$environment = $zc_payment->get_option( 'environment' );

		return 'https://' . $environment . '/api/';
	}

	private static function _sendJsonRequest( $url, $data = array() ) {
		$content     = json_encode( $data );
		$responseObj = $data = wp_remote_post( $url,
		                                       array(
			                                       'headers'     => array( 'Content-Type' => 'application/json; charset=utf-8' ),
			                                       'body'        => $content,
			                                       'method'      => 'POST',
			                                       'data_format' => 'body',
			                                       'sslverify'   => false,
		                                       ) );

		$jsonStr = wp_remote_retrieve_body( $responseObj );
		//connection problem
		if ( is_wp_error( $responseObj ) || wp_remote_retrieve_response_code( $responseObj ) != 200 ) {
			self::$lastResponseDebugStr = "The function wp_remote_post returned an error,\n <br>
											this may be caused by various reasons and can be fixed by your Server IT guy or your developer.\n <br>
											The most common reasons are:\n <br>
											&nbsp;&nbsp; 1. A misconfiguration of the Wordpress.\n <br>
											&nbsp;&nbsp; 2. A problem in the PHP or underlying server configuration that block this method.\n <br>
											&nbsp;&nbsp; 3. A firewall that block the request\n <br>
											Please see the technical details and ask your IT guy to check the connectivity to our servers.\n <br>
											If the response code is empty, it shows that something is blocking the request from even leaving your server.\n <br>
											\n <br>
											<b>technical data:</b> \n <br>
											<u>url</u>: $url \n <br>
											<u>response code</u>: " . wp_remote_retrieve_response_code($responseObj) . " \n <br>
											<u>headers</u>: " . json_encode(is_array(wp_remote_retrieve_headers($responseObj)) ? wp_remote_retrieve_headers($responseObj) : wp_remote_retrieve_headers($responseObj)->getAll()) . " \n <br>
											<u>response_message</u>: " . wp_remote_retrieve_response_message($responseObj) . " \n <br>
											<u>body</u>: " . substr(strip_tags(wp_remote_retrieve_body($responseObj)), 0 ,200). " \n <br>";
		} else {
			self::$lastResponseDebugStr = $jsonStr;
		}

		return json_decode( $jsonStr );
	}

	public static function sendJsonRequest( $url, $data = array() ) {
		//do validation
		$zc_payment = new WC_Gateway_EZcount();
		$zc_payment->init_form_fields();
		$zc_payment->init_settings();
		$data["api_key"]         = $zc_payment->get_option( 'api_key' );
		$data["developer_email"] = $zc_payment->get_option( 'user_email' );

		return self::_sendJsonRequest( $url, $data );
	}

	static public function encrypt( $plaintext, $key ) {
		$ivlen          = openssl_cipher_iv_length( $cipher = "AES-128-CBC" );
		$iv             = openssl_random_pseudo_bytes( $ivlen );
		$ciphertext_raw = openssl_encrypt( $plaintext, $cipher, $key, $options = OPENSSL_RAW_DATA, $iv );
		$hmac           = hash_hmac( 'sha256', $ciphertext_raw, $key, $as_binary = true );
		$ciphertext     = base64_encode( $iv . $hmac . $ciphertext_raw );

		return $ciphertext;
	}

	static public function decrypt( $ciphertext, $key ) {
		$c                  = base64_decode( $ciphertext );
		$ivlen              = openssl_cipher_iv_length( $cipher = "AES-128-CBC" );
		$iv                 = substr( $c, 0, $ivlen );
		$hmac               = substr( $c, $ivlen, $sha2len = 32 );
		$ciphertext_raw     = substr( $c, $ivlen + $sha2len );
		$original_plaintext = openssl_decrypt( $ciphertext_raw, $cipher, $key, $options = OPENSSL_RAW_DATA, $iv );
		$calcmac            = hash_hmac( 'sha256', $ciphertext_raw, $key, $as_binary = true );
		if ( hash_equals( $hmac, $calcmac ) )//PHP 5.6+ timing attack safe comparison
		{
			return $original_plaintext;
		}

		//failed to decrypt
		return '';
	}

    /**
     * sanitized an array
     * @param $arr
     * @return array|mixed
     */
    static public function sanitizedArray($arr = array() ){

        /**
         * on falsy return the original value
         */
        if (empty($arr)){
            return $arr;
        }

        $sanitizedArray = [];
        foreach ($arr as $k=>$v){
            /**
             * on case of falsy keep the original value
             */
            $sanitizedArray[sanitize_text_field($k)] = $v;
            if (!empty($v)){
                $sanitizedArray[sanitize_text_field($k)] = sanitize_text_field($v);
            }
        }
        return $sanitizedArray;
    }
}
